@@ -8,14 +8,16 @@ T = TypeVar("T", bound="ResolveRightsInfo")
 
 @_attrs_define
 class ResolveRightsInfo:
-    """Parameter Class for {@link IXServicePortIF#resolveRights(ClientInfo, UserInfo, ResolveRightsInfo)} ."""
+    """Parameter Class for
+    {@link IXServicePortIF#resolveRights(ClientInfo, UserInfo, ResolveRightsInfo)} .
+
+    """
 
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
 
         return field_dict
 
